==> babel-plugin-smart-import-0.1.9.tgz: package/README.md <==
# babel-plugin-smart-import
This plugin is used to import on demand.

## Install
```
npm install -D babel-plugin-smart-import
```

## Usage
### Use for antd
babel.config.js
```js
var plugins = [
    ['babel-plugin-smart-import', {
        library: 'antd',
        directory: 'lib',           
        namingRule: 'dash',         // use ant/lib/xxx-xxx folder
        style: {                    
            directory: 'style',     
            namingRule: 'index',    // use ant/lib/xxx/style/index file
            ext: 'css'              // js, css or less all fine.
        }
    }]
];
```
app.jsx
```js
import { Button } from 'antd';
ReactDOM.render(<Button>xxxx</Button>);
        ↓
require('antd/lib/button/style/index.css');
var _button = require('antd/lib/button');
ReactDOM.render(<_button>xxxx</_button>);
```
### Use for @material-ui/core
babel.config.js
```js
var plugins = [
    ['babel-plugin-smart-import', {
        library: '@material-ui/core'
    }]
];
```
app.jsx
```js
import { Button } from '@material-ui/core';
ReactDOM.render(<Button>xxxx</Button>);
        ↓
var _button = require('@material-ui/core/Button');
ReactDOM.render(<_button>xxxx</_button>);
```
### Use for elementalui
babel.config.js
```js
var plugins = [
    ['babel-plugin-smart-import', {
        library: 'elemental',
        directory: 'lib/components',
        style: {
            directory: '/less/components',  // start with '/' means follow 'elemental'
            namingRule: 'big-camel',
            ext: 'less'
        }
    }]
];
```
app.jsx
```js
import { Button } from 'elemental';
ReactDOM.render(<Button>xxxx</Button>);
        ↓
require('elemental/less/components/Button.less');
var _button = require('elemental/lib/components/Button');
ReactDOM.render(<_button>xxxx</_button>);
```
### Use multiple plugins
babel.config.js
```js
var plugins = [
    ['babel-plugin-smart-import', {
        library: 'antd',
        directory: 'lib',           
        namingRule: 'dash',         
        style: {                    
            directory: 'style',     
            namingRule: 'index',    
            ext: 'css'              
        }
    }, 'antd'],
    ['babel-plugin-smart-import', {
        library: '@material-ui/core'
    }, '@material-ui/core']
];
```

## Options
```js
{
    library,             
    directory,           
    namingRule,          
    importDefault,       
    style: {             
        directory,       
        namingRule,      
        ext              
    }
}
```
### library
String, this option is required.  
Set library name.
### directory
String, default to null.  
Set components directory.
### namingRule
'little-camel', 'big-camel', 'dash', 'underline' or custom function, default to 'big-camel'.
Set component naming rule(folder or file).
```js
'little-camel'  -> componentName
'big-camel'     -> ComponentName
'dash'          -> component-name
'underline'     -> component_name
function        -> importName => newName
```
### importDefault
Boolean, default to true.
Transform import type to default, false means addNamed.
```js
// true
import default from 'source';
// false
import { named } from 'source';
```
### style
Boolean or Object, default to false.
import related style file.
### style.directory
String, default to components directory.
Set styles directory. if start with '/' then style.directory will append to library otherwise append to component folder. refer to antd and elemental usage above.
### style.namingRule
'little-camel', 'big-camel', 'dash', 'underline', specific name(like 'index') or function, default to null.
Set style naming rule(folder or file).
### style.ext
String, e.g. 'css', 'less', 'sass' or 'js', default to null.
Set style file's extension. if this option is specific, then style.namingRule is files.

==> babel-plugin-smart-import-0.1.10.tgz: package/README.md <==
# babel-plugin-smart-import
This plugin is used to import on demand.

## Install
```
npm install -D babel-plugin-smart-import
```

## Usage
### Use for antd
babel.config.js
```js
var plugins = [
    ['babel-plugin-smart-import', {
        library: 'antd',
        directory: 'lib',           
        namingRule: 'dash',         // use ant/lib/xxx-xxx folder
        style: {                    
            directory: 'style',     
            namingRule: 'index',    // use ant/lib/xxx/style/index file
            ext: 'css'              // js, css or less all fine.
        }
    }]
];
```
app.jsx
```js
import { Button } from 'antd';
ReactDOM.render(<Button>xxxx</Button>);
        ↓
require('antd/lib/button/style/index.css');
var _button = require('antd/lib/button');
ReactDOM.render(<_button>xxxx</_button>);
```
### Use for @material-ui/core
babel.config.js
```js
var plugins = [
    ['babel-plugin-smart-import', {
        library: '@material-ui/core'
    }]
];
```
app.jsx
```js
import { Button } from '@material-ui/core';
ReactDOM.render(<Button>xxxx</Button>);
        ↓
var _button = require('@material-ui/core/Button');
ReactDOM.render(<_button>xxxx</_button>);
```
### Use for elemental-ui
babel.config.js
```js
var plugins = [
    ['babel-plugin-smart-import', {
        library: 'elemental',
        directory: 'lib/components',
        style: {
            directory: '/less/components',  // start with '/' means follow 'elemental'
            namingRule: 'big-camel',
            ext: 'less'
        }
    }]
];
```
app.jsx
```js
import { Button } from 'elemental';
ReactDOM.render(<Button>xxxx</Button>);
        ↓
require('elemental/less/components/Button.less');
var _button = require('elemental/lib/components/Button');
ReactDOM.render(<_button>xxxx</_button>);
```
### Use multiple plugins
babel.config.js
```js
var plugins = [
    ['babel-plugin-smart-import', {
        library: 'antd',
        directory: 'lib',           
        namingRule: 'dash',         
        style: {                    
            directory: 'style',     
            namingRule: 'index',    
            ext: 'css'              
        }
    }, 'antd'],
    ['babel-plugin-smart-import', {
        library: '@material-ui/core'
    }, '@material-ui/core']
];
```

## Options
```js
{
    library,             
    directory,           
    namingRule,          
    importDefault,       
    style: {             
        directory,       
        namingRule,      
        ext              
    }
}
```
### library
String, this option is required.  
Set library name.
### directory
String, default to null.  
Set components directory.
### namingRule
'little-camel', 'big-camel', 'dash', 'underline' or custom function, default to 'big-camel'.
Set component naming rule(folder or file).
```js
'little-camel'  -> componentName
'big-camel'     -> ComponentName
'dash'          -> component-name
'underline'     -> component_name
function        -> importName => newName
```
### importDefault
Boolean, default to true.
Transform import type to default, false means addNamed.
```js
// true
import default from 'source';
// false
import { named } from 'source';
```
### style
Boolean or Object, default to false.
import related style file.
### style.directory
String, default to components directory.
Set styles directory. if start with '/' then style.directory will append to library otherwise append to component folder. refer to antd and elemental usage above.
### style.namingRule
'little-camel', 'big-camel', 'dash', 'underline', specific name(like 'index') or function, default to null.
Set style naming rule(folder or file).
### style.ext
String, e.g. 'css', 'less', 'sass' or 'js', default to null.
Set style file's extension. if this option is specific, then style.namingRule is files.
